@@ -20,7 +20,7 @@
 #' Radical arguments that use the prefix \code{al.} designate
 #' alternative solutions for each of the applied rules
 #' throughout the options by following a Solutions Combination
-#' Design (Blum et al., 2016). They are random by defect when
+#' Design (Blum et al., 2016). They are random by default when
 #' \code{automatic=T}. When \code{automatic=F}, values must be
 #' chosen, which designate rotation angles between the correct
 #' and the alternative solutions, or alternative mirroring /
@@ -32,7 +32,7 @@
 #' \code{add.rule} designates a specific rule from 1 to 5,
 #' then the latter statement is only valid for this rule.
 #' 2. Two alternative solutions should be chosen for each rule
-#' of two rule-based items.
+#' of two-rule-based items.
 #' 3. One alternative solution should be chosen for each rule
 #' of items comprising more than two rules.
 #'
@@ -40,114 +40,144 @@
 #' @param main.rot A numeric vector with two main shape rotation values multiple of 45 and between -135 and 180. No rotation: 0.
 #' @param mirror A number designating mirroring presence or no mirroring (i.e., 1 or 0).
 #' @param trap.rot A numeric vector with two trapezium rotation values multiple of 45 and between -135 and 180. No rotation: 0.
-#' @param subtract A numeric vector with two internal line subtractions from 1 to 5, or letter "R" for a random two-line subtraction. No subtraction: 0.
+#' @param subtract A numeric vector with two internal lines to subtract from 1 to 5, or letter "R" for a random subtraction. No subtraction: 0.
 #' @param dot.mov A numeric vector with two dot edge movements from 1 to 6. No dot edge movement: 0.
-#' @param a.main A number of rotation state of the main shape of Figure A from 1 to 8. Random by defect.
-#' @param a.flip A number designating whether Figure A is flipped with respect to its vertical axis or not (i.e., 1 or 0). Random by defect.
-#' @param a.trap A number of rotation state of the trapezium of Figure A from 1 to 8. Random by defect.
-#' @param a.dot A number of dot edge position of Figure A from 1 to 6. Random by defect.
-#' @param constrict Character string designating a part of Figure A to display all possible positions every 'n' isomorphs.
-#' @param al.main.rot A numeric vector with alternative main shape rotation solutions. Random by defect.
-#' @param al.mirror A numeric vector with alternative mirroring solutions. Random by defect.
-#' @param al.trap.rot A numeric vector with alternative trapezium rotation solutions. Random by defect.
-#' @param al.subtract A numeric vector with alternative subtraction solutions. Random by defect.
-#' @param al.dot.mov A numeric vector with alternative dot edge movement solutions. Random by defect.
-#' @param correct A number from 1 to 9 for correct response placement. Random by defect.
-#' @param add.rule A number specifying which rule from 1 to 5 adds itself to the options of one-rule based items. Random by defect.
-#' @param automatic Should options be generated by the program? True by defect.
+#' @param a.main A numeric vector with possible rotation states of the main shape of Figure A from 1 to 8. Random by default.
+#' @param a.flip A logical value designating whether Figure A is flipped with respect to its vertical axis or not (i.e., T or F). Random by default.
+#' @param a.trap A numeric vector with possible rotation states of the trapezium of Figure A from 1 to 8. Random by default.
+#' @param a.dot A numeric vector with possible dot edge positions of Figure A from 1 to 6. Random by default.
+#' @param constrict A character string designating a part of Figure A to display all possible positions every 'n' isomorphs.
+#' @param al.main.rot A numeric vector with alternative main shape rotation solutions. Random by default.
+#' @param al.mirror A numeric vector with alternative mirroring solutions. Random by default.
+#' @param al.trap.rot A numeric vector with alternative trapezium rotation solutions. Random by default.
+#' @param al.subtract A numeric vector with alternative subtraction solutions. Random by default.
+#' @param al.dot.mov A numeric vector with alternative dot edge movement solutions. Random by default.
+#' @param correct A vector with numbers ranging from 1 to 9 for correct response placements. Random by default.
+#' @param add.rule A number specifying which rule from 1 to 5 adds itself to the options of one-rule-based items. Random by default.
+#' @param automatic Should options be generated by the program? True by default.
 #' @return An object of class \code{'fa_items'}, basically a list including elements to be plotted with function \code{\link{plot_fa}}.
 #' @author Diego Blum \email{<blumworx@gmail.com>}
-#' @references Blum, D., Holling, H., Galibert, M.S., & Forthmann, B. (2016, in review). Task difficulty prediction of figural analogies. \emph{Intelligence}.
+#' @references Blum, D., Holling, H., Galibert, M.S., & Forthmann, B. (2016, in press). Task difficulty prediction of figural analogies. \emph{Intelligence}.
 #' @seealso \code{\link{IMak}}
 #' @examples
-#' \dontrun{Create two isomorphs with one rule, setting the correct answer to 1:}
+#' ## Create two isomorphs with one rule, setting the correct answer to 1:
 #' one <- build_fa(isomorphs = 2, dot.mov = c(1, 2), correct = 1)
-#' \dontrun{Plot them:}
+#' ## Plot them:
 #' plot_fa(one)
 #'
-#' \dontrun{Create four isomorphs with two rules:}
+#' ## Create four isomorphs with two rules:
 #' two <- build_fa(isomorphs = 4, main.rot = c(180, 135), trap.rot = c(90, 45))
-#' \dontrun{Plot them:}
+#' ## Plot them:
 #' plot_fa(two)
 #'
-#' \dontrun{Create 20 isomorphs with three rules. Set \code{automatic=F} and affect the options:}
+#' ## Create 20 isomorphs with three rules. Set automatic=F and affect the options:
 #' three <- build_fa(isomorphs = 20, mirror = 1, trap.rot = c(90, 45), dot.mov = c(1, 2),
 #' automatic = FALSE, al.mirror = c(0, 1), al.trap.rot = -45, al.dot.mov = 1)
-#' \dontrun{Plot them:}
+#' ## Plot them:
 #' plot_fa(three)
 #'
-#' \dontrun{Create and plot four two-rule based isomorphs, all of them comprising the same Figure A:}
+#' ## Create and plot four two-rule based isomorphs, all of them comprising the same Figure A:
 #' four <- build_fa(isomorphs = 4, a.main = 1, a.flip = FALSE, a.trap = 2, a.dot = 6,
 #' mirror = 1, subtract = "R")
 #' plot_fa(four)
 #'
-#' \dontrun{Create and plot 16 isomorphs by constricting the main shape rotation rule:}
+#' ## Create and plot 16 isomorphs by constricting the main shape rotation rule:
 #' five <- build_fa(isomorphs = 16, subtract = c(1, 4), constrict = "main")
 #' plot_fa(five)
 #' @export
 build_fa <- function(
-  isomorphs = 1,        #Number of isomorphs.
-  main.rot = c(0, 0),   #Main shape rotation rule.
-  mirror = 0,           #Mirroring rule.
-  trap.rot = c(0, 0),   #Trapezium rotation rule.
-  subtract = c(0, 0),   #Subtraction rule.
-  dot.mov = c(0, 0),    #Dot edge movement rule.
-  a.main = "R",         #F: random. 1:8 are positions.
-  a.flip = "R",         #F: random. T, F: presence / absence.
-  a.trap = "R",         #F: random. 1:8 are positions.
-  a.dot = "R",          #F: random. 1:6 are positions.
-  constrict = F,        #Values: "main", "trap", "dot".
-  al.main.rot = 0,      #Select up to three different degrees to swap from the D main rotation.
-  al.mirror = 0,        #Select up to three degrees and three 1 or 0 mirrorings to swap from d.
-                        #Pairs 1 & 2, 3 & 4, 5 & 6 hold rules of
-                        #main shape rotation (first element
-                        #of the pair) and mirroring (second element).
-  al.trap.rot = 0,      #Select up to three degrees to swap from the D trapezium rotation.
-  al.subtract = 0,      #Select up to three pairs of boot eliminations, where
-                        #pairs 1 & 2, 3 & 4, 5 & 6 hold two numbers of boot line
-                        #elimination from 1 to 5 each.
-  al.dot.mov = 0,       #Place the dot in a different position from
-                        #1 to 6.
-  correct = 0,          #Placing of correct response. 0: random place from 1 to 8 or none.
-                        #1-8: position. 9: none is correct.
-  add.rule = 0,         #Add specific rule to the options when working with one rule.
-                        #0: Random. 1 to 5: rule added. -1: No rule added.
-  automatic = T)        #Let the program construct the options automatically. True by defect.
+  isomorphs = 1,
+  main.rot = c(0, 0),
+  mirror = 0,
+  trap.rot = c(0, 0),
+  subtract = c(0, 0),
+  dot.mov = c(0, 0),
+  a.main = "R",
+  a.flip = "R",
+  a.trap = "R",
+  a.dot = "R",
+  constrict = F,
+  al.main.rot = 0,
+  al.mirror = 0,
+  al.trap.rot = 0,
+  al.subtract = 0,
+  al.dot.mov = 0,
+  correct = 0,
+  add.rule = 0,
+  automatic = T)
 
   {
 
-#Restrictions to the values chosen for Figure A:
-if (!a.main %in% c("R", 1:8) |
-    !a.flip %in% c("R", F, T) |
-    !a.trap %in% c("R", 1:8) |
-    !a.dot %in% c("R", 1:6) |
-    !constrict %in% c(F, "main", "trap", "dot"))
+# Restrictions to the values chosen for Figure A:
+if ((! sum(a.main %in% 1:8) == length(a.main) &
+       ! a.main[1] == "R") |
+    (! sum(a.flip %in% c("R", F, T)) == length(a.flip) &
+       ! a.flip[1] == "R") |
+    length(a.flip) > 1 |
+    (! sum(a.trap %in% c("R", 1:8)) == length(a.trap) &
+       ! a.trap[1] == "R") |
+    (! sum(a.dot %in% c("R", 1:6)) == length(a.dot) &
+       ! a.dot[1] == "R") |
+    ! constrict %in% c(F, "main", "trap", "dot") |
+    length(constrict) > 1)
   stop("Only the following can be applied to Figure A:
        Main shape or trapezium values from 1 to 8.
-       Flipping presence (1) or absence (0).
+       One flipping value of presence (T) or absence (F).
        Dot edge values from 1 to 6.
-       Constriction labels 'main', 'trap' or 'dot'.")
-if (!isomorphs > 0) stop("Invalid number of isomorphs.")
+       One constriction label: \"main\", \"trap\" or \"dot\".")
+if (! isomorphs > 0) stop("Invalid number of isomorphs.")
+if (sum(duplicated(a.main)) > 0 |
+    sum(duplicated(a.trap)) > 0 |
+    sum(duplicated(a.dot)) > 0)
+  stop("Attempt to replicate a Figure A position.")
+if (! sum(correct %in% 1:9) == length(correct) &
+    ! correct[1] == 0)
+  stop("Failure in assignment of correct answers.")
 
 .Random.seed <- 0
 rm(.Random.seed)
 
-#Values for a randomized Figure A according to choices:
+# How to extract random rows:
 randomRows <- function(df, n=1) {
   return(df[sample(nrow(df), n),])
 }
+
+# Values for a randomized Figure A according to choices:
 rangle <- c(-135, -90, -45, 0, 45, 90, 135, 180)
 rdot <- 1:6
+
+# Defining angles for the main shape of Figure A:
+if (a.main[1] != "R") {
+  for (i in 1:length(a.main)) {
+    a.main[i] <- switch(a.main[i],
+                    "1" = 0, "2" = 45, "3" = 90, "4" = 135,
+                    "5" = 180, "6" = -135, "7" = -90, "8" = -45)
+  }} else a.main <- rangle
+
+# Defining 1 or 0 for flipping of Figure A:
+if (a.flip != "R") {
+   a.flip <- if(a.flip == F) 0 else 1
+  } else a.flip <- 0:1
+
+# Defining angles for the trapezium of Figure A:
+if (a.trap[1] != "R") {
+  for (i in 1:length(a.trap)) {
+    a.trap[i] <- switch(a.trap[i],
+                        "1" = 0, "2" = 45, "3" = 90, "4" = 135,
+                        "5" = 180, "6" = -135, "7" = -90, "8" = -45)
+  }} else a.trap <- rangle
+
+# Defining edge positions for the dot of Figure A:
+if (a.dot[1] == "R") a.dot <- rdot
+
 combinations <- list(
-  firstrule <- if (a.main == "R") rangle else NA,
-  secondrule <- if (a.flip == "R") 0:1 else NA,
-  thirdrule <- if (a.trap == "R") rangle else NA,
-  fifthrule <- if (a.dot == "R") rdot else NA)
+  firstrule <- a.main,
+  secondrule <- a.flip,
+  thirdrule <- a.trap,
+  fifthrule <- a.dot)
 names(combinations) <- c("main", "flip", "trap", "dot")
 
-#Number of combinations:
-if (a.main == "R" | a.flip == "R" | a.trap == "R" | a.dot == "R"){
-
+# Number of combinations:
 product <- 1
 number_comb <- combinations
 number_comb <- number_comb[!is.na(number_comb)]
@@ -160,20 +190,18 @@ random.list <- expand.grid(combinations)
 random.list <- as.matrix(random.list)
 random.list <- randomRows(random.list, n=length(random.list[,1]))
 
-#Constricting to a shape part, so that different positions appear every 'n' times:
-if ((constrict == "main" & a.main == "R" & a.flip == "R") |
-    (constrict == "trap" & a.trap == "R") |
-    (constrict == "dot" & a.dot == "R")) {
+# Constricting to a shape part, so that different positions appear every 'n' times:
+if (constrict %in% c("main","trap","dot") & product > 1) {
   constriction <- switch (constrict,
-                          "main" = sample(rangle, 8),
-                          "trap" = sample(rangle, 8),
-                          "dot" = sample(rdot, 6))
+                          "main" = a.main,
+                          "trap" = a.trap,
+                          "dot" = a.dot)
   constr.column <- switch (constrict,
                            "main" = 1,
                            "trap" = 3,
                            "dot" = 4)
-  if (constrict == "main"){
-    random.list <- random.list[order(match(random.list[,2], constriction)),]
+  if (constrict == "main" & length(a.flip) > 1) {
+    random.list <- random.list[order(match(random.list[,2], 0:1)),]
     more <- 2
     } else
       more <- 1
@@ -188,42 +216,49 @@ if ((constrict == "main" & a.main == "R" & a.flip == "R") |
   random.list <- rrll[-1,]
 }
 
-#Replicate list according to the number of isomorphs:
+# Replicate list according to the number of isomorphs:
 table_multiplier <- ceiling(isomorphs/product)
-if (table_multiplier > 1) warning(paste("At least one item matrix after item",
-                         product, "may match the matrix of a previous item."))
+if (table_multiplier > 1) {
+  if (length(a.main) != 1 | length(a.trap) != 1 |
+      length(a.flip) != 1 | length(a.dot) != 1) {
+    warning(paste("At least one item matrix after item",
+                  product, "may match the matrix of a previous item."))
+  } else {
+    warning(paste("All item matrices may match."))
+}}
 random.alt <- random.list
 if (table_multiplier > 1) for (i in 2:table_multiplier)
   random.list <- rbind(random.list, random.alt)
 
-} else
-    warning("All isomorphs comprise the same information to build the matrix. Only the subtraction rule is allowed to vary.")
+# Replicate list of correct answers according to the number of isomorphs:
+if (correct[1] == 0) {
+  correct <- sample(1:9, size = isomorphs, replace = T)
+} else {
+  correct_multiplier <- ceiling(isomorphs/length(correct))
+  correct.alt <- correct
+  if (correct_multiplier > 1) for (i in 2:correct_multiplier)
+    correct <- c(correct, correct.alt)
+}
 
-#Creating features for every isomorph
-#It goes almost untill the end of the function!:
+# Creating features for every isomorph
+# It goes almost until the end of the function!:
 for (l in 1:isomorphs){
 
-#MATRIX
+# MATRIX
 
-#List of features for figure A:
+# List of features for figure A:
 a <- list(
-  rotation = if (a.main != "R")
-    switch(a.main, "1" = 0, "2" = 45, "3" = 90, "4" = 135,
-                  "5" = 180, "6" = -135, "7" = -90, "8" = -45) else
-                  random.list[,"main"][l],
-  mirror = if (a.flip != "R") a.flip else random.list[,"flip"][l],
-  hampos = if (a.trap != "R")
-    switch(a.trap, "1" = 0, "2" = 45, "3" = 90, "4" = 135,
-                  "5" = 180, "6" = -135, "7" = -90, "8" = -45) else
-                    random.list[,"trap"][l],
+  rotation = random.list[,"main"][[l]],
+  mirror = random.list[,"flip"][[l]],
+  hampos = random.list[,"trap"][[l]],
   bootlines = c(1, 1, 1, 1, 1),
-  dotpos = if (a.dot != "R") a.dot else random.list[,"dot"][l])
+  dotpos = random.list[,"dot"][[l]])
 
-#For now, we equal figures A, B and C:
+# For now, we equal figures A, B and C:
 b <- a
 c <- a
 
-#Function for changing B and C properties according to rules:
+# Function for changing B and C properties according to rules:
 apply_rule <- function(x, rule, degree, pos){
   if (rule == "rotate.m") x[[1]] <- x[[1]] + degree
   if (rule == "mirror.a")
@@ -242,7 +277,7 @@ apply_rule <- function(x, rule, degree, pos){
   return(x)
 }
 
-#Function that calls apply_rule and is further assigned to a list:
+# Function that calls apply_rule and is further assigned to a list:
 shape_matrix <- function(x) {
   if(x$circle_rotation[1] != 0 & x$circle_rotation[2] != 0 & x$mirroring == 1)
     stop("Main shape rotation and mirroring cannot coexist.")
@@ -299,7 +334,7 @@ shape_matrix <- function(x) {
   return(list(a=a, b=b, c=c))
 }
 
-#Random subtraction or fixed lines:
+# Random subtraction or fixed lines:
 r_subt <- matrix(ncol = 2, byrow = T,
                  c(1, 3, 3, 5, 5, 3, 3, 1,
                    1, 4, 2, 5, 5, 2, 4, 1))
@@ -316,7 +351,7 @@ r_subt <- matrix(r_subt[!is.na(r_subt)], ncol = 2)
 subchoice <- if (subtract[1] == "R") randomRows(r_subt) else
   subtract
 
-#List and class for this list:
+# List and class for this list:
 matrix <- list(
   circle_rotation = main.rot,
   mirroring = mirror,
@@ -325,12 +360,12 @@ matrix <- list(
   dot_movement = dot.mov)
 out <- shape_matrix(matrix)
 
-#Create A, B and C again:
+# Create A, B and C again:
 a <- out$a
 b <- out$b
 c <- out$c
 
-#Create values for correct answer D:
+# Create values for correct answer D:
 correct_rot <- if (a[[2]] != b[[2]]) a[[1]] + 180 else
                    b[[1]] - a[[1]] + c[[1]]
 correct_boot <- 0
@@ -345,7 +380,7 @@ d <- list(
   bootlines = correct_boot,
   dotpos = b[[5]]-a[[5]] + c[[5]])
 
-#Correction of the rotation angle:
+# Correction of the rotation angle:
 one_rot <- c(1, 3)
 for (i in 1:2){
   if (b[[one_rot[i]]] > 180) b[[one_rot[i]]] <- b[[one_rot[i]]] - 360
@@ -355,13 +390,13 @@ for (i in 1:2){
   if (d[[one_rot[i]]] > 180) d[[one_rot[i]]] <- d[[one_rot[i]]] - 360
   if (d[[one_rot[i]]] < (-135))   d[[one_rot[i]]] <- d[[one_rot[i]]] + 360}
 
-#OPTIONS
+# OPTIONS
 
-#Function to create options according to the
-#Solutions Combination Design (Blum, Holling, Galibert, & Forthmann 2016):
+# Function to create options according to the
+# Solutions Combination Design (Blum, Holling, Galibert, & Forthmann 2016):
 shape_options <- function(x){
 
-  #Presence of each rule (0 if not present, 1 if pesent):
+  # Presence of each rule (0 if not present, 1 if pesent):
   rulePresence <- 0
   for (i in 1:5) {
     ifelse (b[[i]] == a[[i]] & c[[i]] == a[[i]],
@@ -369,7 +404,7 @@ shape_options <- function(x){
   }
   if (rulePresence[2] == 1) rulePresence[1] <- 0
 
-  #Numbers of rules being used:
+  # Numbers of rules being used:
   numPresence <- 0
   for (i in 1:5) {
     if (rulePresence[i] == 1)
@@ -377,20 +412,20 @@ shape_options <- function(x){
   }
   numPresence <- numPresence[!is.na(numPresence)]
 
-  #Numbers of rules not being used:
+  # Numbers of rules not being used:
   numAbsence <- 1:5
   for (i in 1:5) {
     if (i %in% numPresence) numAbsence[i] <- NA
   }
   numAbsence <- numAbsence[!is.na(numAbsence)]
 
-  #Random right answer:
+  # Random right answer:
   if (x$correct == 0) {
     x$correct <- sample(1:9, 1)
     random_answer <- T
   } else random_answer <- F
 
-  #Forbidden:
+  # Forbidden:
   if (x$correct > 9) stop("Correct answer number out of bounds.")
   if (sum(rulePresence) > 1 & x$add > 0)
     warning("No extra rule needed when working with more than one rule. Added rule discarded.")
@@ -400,7 +435,7 @@ shape_options <- function(x){
     stop("Attempt to add same rule as the one being already used.")
   if (x$add %in% -1:5 == F & sum(rulePresence) == 1) stop("Added rule number out of bounds.")
 
-  #Creating matrices and a function to sample matrix rows:
+  # Creating matrices and a function to sample matrix rows:
   bootmatrix1 <- matrix(c(0, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1,
                           0, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1,
                           0), ncol=5, byrow=TRUE)
@@ -409,10 +444,10 @@ shape_options <- function(x){
                           1), ncol=5, byrow=TRUE)
   bootmatrix3 <- rbind(bootmatrix1, bootmatrix2)
 
-  #WORKING WITH ONLY ONE RULE FOR BOTH MATRIX AND OPTIONS:
+  # WORKING WITH ONLY ONE RULE FOR BOTH MATRIX AND OPTIONS:
   if (x$add == -1 & sum(rulePresence) == 1){
 
-    #Creating vectors of angle positions from D:
+    # Creating vectors of angle positions from D:
     rangle45from_d1 <- c(d[[1]] + 45, d[[1]] + 90,
                          d[[1]] + 135, d[[1]] + 180,
                          d[[1]] + 225, d[[1]] + 270,
@@ -424,7 +459,7 @@ shape_options <- function(x){
     rangle90from_d <- c(d[[1]], d[[1]] + 90,
                         d[[1]] + 180, d[[1]] + 270)
 
-    #Creating a list of angle and mirror positions:
+    # Creating a list of angle and mirror positions:
     rmirrorlist <- list(
       rbind(rangle90from_d[1], !d[[2]]),
       rbind(rangle90from_d[2], d[[2]]),
@@ -434,13 +469,13 @@ shape_options <- function(x){
       rbind(rangle90from_d[4], d[[2]]),
       rbind(rangle90from_d[4], !d[[2]]))
 
-    #Randomizing the latter information:
+    # Randomizing the latter information:
     samples_ra45d1 <- sample(rangle45from_d1, 7, replace=FALSE)
     samples_ra90d1 <- sample(rangle90from_d, 4, replace=FALSE)
     samples_ra45d3 <- sample(rangle45from_d3, 7, replace=FALSE)
     samples_mirror <- sample(rmirrorlist, 7, replace=FALSE)
 
-    #Getting D's bootline information:
+    # Getting D's bootline information:
     samples_bootrows <- bootmatrix3[sample(nrow(bootmatrix3), 9),]
     for (i in 1:9) {
       if (sum(ifelse(samples_bootrows[i,] == d[[4]], 1, 0)) == 5)
@@ -449,14 +484,14 @@ shape_options <- function(x){
     samples_bootrows <- samples_bootrows[!is.na(samples_bootrows)]
     samples_bootrows <- matrix(samples_bootrows, ncol=5)
 
-    #Creating a list of lists, each containing information from D:
+    # Creating a list of lists, each containing information from D:
     setlength <- 8
     set <- 1:setlength
     set <- as.list(set)
     for (i in 1:setlength) set[i] <- as.list(set[i])
     for (i in 1:setlength) set[[i]] <- d
 
-    #Main shape rotation:
+    # Main shape rotation:
     if (rulePresence[1] == 1){
       warning("No more than eight computable answer options. 'None is correct' cannot be the right answer.")
       if (x$correct == 9) {
@@ -478,7 +513,7 @@ shape_options <- function(x){
 
     } else
 
-    #Hammer rotation:
+    # Hammer rotation:
     if (rulePresence[3] == 1){
         warning("No more than eight computable answer options. 'None is correct' cannot be the right answer.")
      if (x$correct == 9) {
@@ -502,7 +537,7 @@ shape_options <- function(x){
 
      } else
 
-      #Mirroring:
+      # Mirroring:
      if (rulePresence[2] == 1){
       warning("No more than eight computable answer options. 'None is correct' cannot be the right answer.")
       if (x$correct == 9) {
@@ -528,7 +563,7 @@ shape_options <- function(x){
 
      } else
 
-     #Subtraction:
+     # Subtraction:
      if (rulePresence[4] == 1) {
        for (j in 1:7) {
          if (x$correct == j)
@@ -546,15 +581,15 @@ shape_options <- function(x){
 
      } else
 
-     #Dot movement:
+     # Dot movement:
      if (rulePresence[5] == 1)
        stop("No more than six computable answer options for dot edge movement. Cannot build item list.")
 
   } else {
 
-  #WORKING WITH MORE THAN ONE RULE THROUGHOUT THE OPTIONS:
+  # WORKING WITH MORE THAN ONE RULE THROUGHOUT THE OPTIONS:
 
-  #Adding a random rule only when working with one rule:
+  # Adding a random rule only when working with one rule:
   if (sum(rulePresence) == 1) {
     numAvailable <- numAbsence
     if (rulePresence[1] + rulePresence[2] == 1)
@@ -564,10 +599,10 @@ shape_options <- function(x){
         x$add <- sample(numAvailable, 1)
   }} else x$add <- 0
 
-  #Creating matrices for each rule, where the correct
-  #answer is the first row, and then randomizing the rows:
+  # Creating matrices for each rule, where the correct
+  # answer is the first row, and then randomizing the rows:
 
-  #Rule 2:
+  # Rule 2:
   if (rulePresence[2] == 1 | x$add == 2) {
     if (x$automatic == F){
      if (length(x$swap2) == 1 | length(x$swap2) == 3 | length(x$swap2) == 5)
@@ -601,7 +636,7 @@ shape_options <- function(x){
     }
     mirs <- matrix(mirvec, ncol=2, byrow=T)
     mirs <- rbind(c(d[[1]], d[[2]]), mirs)
-    #Random rows:
+    # Random rows:
     vectormirs <- sample(nrow(mirs), nrow(mirs))
     mirlines <- mirs
     for (i in 1:length(vectormirs)) mirlines[i,] <- mirs[vectormirs[i],]
@@ -609,7 +644,7 @@ shape_options <- function(x){
     main <- matrix(mirlines[,1],ncol=1)
    } else
 
-   #Rule 1:
+   # Rule 1:
     if (rulePresence[1] == 1 | x$add == 1) {
       if (x$automatic == F) {
          for (j in 1:length(x$swap1)) {
@@ -634,7 +669,7 @@ shape_options <- function(x){
        }}
       main <- matrix(mainvec, ncol=1)
       main <- rbind(d[[1]], main)
-      #Random rows:
+      # Random rows:
       main <- randomRows(main, length(main))
       main <- matrix(main, ncol=1)
       mirs <- matrix(d[[2]])
@@ -642,7 +677,7 @@ shape_options <- function(x){
     main <- matrix(d[[1]])
     mirs <- matrix(d[[2]])}
 
-  #Rule 3:
+  # Rule 3:
   if (rulePresence[3] == 1 | x$add == 3) {
     if (x$automatic == F) {
       for (j in 1:length(x$swap3)) {
@@ -668,12 +703,12 @@ shape_options <- function(x){
      }}
     ham <- matrix(hamvec, ncol=1)
     ham <- rbind(d[[3]], ham)
-    #Random rows:
+    # Random rows:
     ham <- randomRows(ham, length(ham))
     ham <- as.matrix(ham, ncol=1)
    } else ham <- matrix(d[[3]])
 
-  #Rule 4:
+  # Rule 4:
   if (rulePresence[4] == 1 | x$add == 4) {
     if (x$automatic == F) {
       if (length(x$swap4) == 1 | length(x$swap4) == 3 | length(x$swap4) == 5)
@@ -717,14 +752,14 @@ shape_options <- function(x){
       if (sum(rulePresence) == 2) subs <- randomRows(subs, 2)
     }
     subs <- rbind(d[[4]], subs)
-    #Random rows:
+    # Random rows:
     vectorsubs <- sample(nrow(subs), nrow(subs))
     sublines <- subs
     for (i in 1:length(vectorsubs)) sublines[i,] <- subs[vectorsubs[i],]
     subs <- sublines
    } else subs <- matrix(d[[4]], ncol=5)
 
-  #Rule 5:
+  # Rule 5:
   if (rulePresence[5] == 1 | x$add == 5) {
     dotleft <- 1:6
     for (i in 1:6) {
@@ -752,7 +787,7 @@ shape_options <- function(x){
     }
     dot <- matrix(dotvec, ncol=1)
     dot <- rbind(d[[5]], dot)
-    #Random rows:
+    # Random rows:
     dot <- randomRows(dot, length(dot))
     dot <- as.matrix(dot, ncol=1)
   } else dot <- matrix(d[[5]])
@@ -763,7 +798,7 @@ shape_options <- function(x){
   }
   if (sum(thecount) > 1) stop("The correct dot edge placement coincides with at least one alternative placement.")
 
-  #Creating a vector of solutions per rule:
+  # Creating a vector of solutions per rule:
   solutions <- rep(0, times=5)
   solutions <- as.list(solutions)
   solutions[[1]] <- main
@@ -772,7 +807,7 @@ shape_options <- function(x){
   solutions[[4]] <- subs
   solutions[[5]] <- dot
 
-  #Correcting angle numbers again, just in case:
+  # Correcting angle numbers again, just in case:
   if ((rulePresence[1] + rulePresence[2] == 1) | x$add == 1 | x$add == 2)
     for (i in 1:length(solutions[[1]])) {
      solutions[[1]][i,] <- if (solutions[[1]][i,] > 180) solutions[[1]][i,] - 360 else solutions[[1]][i,]
@@ -784,7 +819,7 @@ shape_options <- function(x){
      solutions[[3]][i,] <- if (solutions[[3]][i,] < (-135)) solutions[[3]][i,] + 360 else solutions[[3]][i,]
     }
 
-  #Creating a list of lists, each containing information from D:
+  # Creating a list of lists, each containing information from D:
   increment <- if (sum(rulePresence) == 4) 7 else 0
   setlength <- 9 + increment
   set <- 1:setlength
@@ -792,8 +827,8 @@ shape_options <- function(x){
   for (i in 1:setlength) set[i] <- as.list(set[i])
   for (i in 1:setlength) set[[i]] <- d
 
-  #Combinations for one rule in a 4x2 design by defect (it is compulsory to
-  #add one more solution of another rule):
+  # Combinations for one rule in a 4x2 design by default (it is compulsory to
+  # add one more solution of another rule):
   if (sum(rulePresence) == 1) {
     set[[9]] <- NA
     set <- set[!is.na(set)]
@@ -826,7 +861,7 @@ shape_options <- function(x){
         }
    }
 
-  #Combinations for two rules in a 3x3 design by defect:
+  # Combinations for two rules in a 3x3 design by default:
   if (sum(rulePresence) == 2) {
     if (sum(length(solutions[[numPresence[1]]][,1]) == 3,
             length(solutions[[numPresence[2]]][,1]) == 3) != 2)
@@ -847,8 +882,8 @@ shape_options <- function(x){
         set[[i + 3]][[numPresence[2]]] <- solutions[[numPresence[2]]][2,]
         set[[i + 6]][[numPresence[2]]] <- solutions[[numPresence[2]]][3,]
     }
-    #For the case of a 3x3 design, when one answer is correct,
-    #we eliminate an option:
+    # For the case of a 3x3 design, when one answer is correct,
+    # we eliminate an option:
     if (x$correct < 9) {
       dif1=0
       dif2=0
@@ -873,7 +908,7 @@ shape_options <- function(x){
     }
   }
 
-  #Combinations for three rules in a 2x2x2 design by defect:
+  # Combinations for three rules in a 2x2x2 design by default:
   if (sum(rulePresence) == 3) {
     if (sum(length(solutions[[numPresence[1]]][,1]) == 2,
             length(solutions[[numPresence[2]]][,1]) == 2,
@@ -904,7 +939,7 @@ shape_options <- function(x){
     }
   }
 
-  #Combinations for four rules with a 2x2x2x2 design by defect:
+  # Combinations for four rules with a 2x2x2x2 design by default:
   if (sum(rulePresence) == 4) {
     if ((sum(length(solutions[[numPresence[1]]][,1]) == 2,
              length(solutions[[numPresence[2]]][,1]) == 2,
@@ -952,7 +987,7 @@ shape_options <- function(x){
       set[[i]][[numPresence[4]]] <- solutions[[numPresence[4]]][1,]
       set[[i + 8]][[numPresence[4]]] <- solutions[[numPresence[4]]][2,]
     }
-    #Eliminating options that have three or one rule equal to D:
+    # Eliminating options that have three or one rule equal to D:
     dif1=0
     dif2=0
     dif3=0
@@ -968,21 +1003,21 @@ shape_options <- function(x){
     set <- set[!is.na(set)]
   }
 
-  #Random distribution of options:
+  # Random distribution of options:
   numbersset <- c(1:length(set))
   rset <- sample(numbersset, length(set))
   set2 <- set
   for (i in 1:length(set)) set[[i]] <- set2[[rset[i]]]
 
-  #Subtracting the option equal to D:
+  # Subtracting the option equal to D:
   for (i in 1:length(set)) {
     if (sum(ifelse(unlist(set[[i]]) == unlist(d), 1, 0)) == 9)
       set[[i]] <- NA
   }
   set <- set[!is.na(set)]
 
-  #When there are seven options and no correct answer, we create
-  #the 8th option based on the random alteration of a rule:
+  # When there are seven options and no correct answer, we create
+  # the 8th option based on the random alteration of a rule:
   if (length(set) == 7 & x$correct == 9) {
     rangle1 <- matrix(rangle[!rangle %in% solutions[[1]]], ncol=1)
     rangle2 <- matrix(rangle[!rangle %in% solutions[[3]]], ncol=1)
@@ -1029,8 +1064,8 @@ shape_options <- function(x){
       set[[i]] <- set3[[rset[i]]]
   }
 
-  #Placing the correct option when there are seven options
-  #and a defined location of the correct answer:
+  # Placing the correct option when there are seven options
+  # and a defined location of the correct answer:
   if (length(set) == 7 & x$correct < 9) {
     set4 <- set
     for (k in 1:8) if (x$correct == k) set[[k]] <- d
@@ -1042,12 +1077,12 @@ shape_options <- function(x){
         set[[i]] <- set4[[i + (8-j)]]
   }
 
-  #Naming the 8 options:
+  # Naming the 8 options:
   for (i in 1:8) names(set)[i] <-
     paste("op", i, sep="")
   }
 
-  #Final phase:
+  # Final phase:
   shapes <- c("a", "b", "c", "info")
   for (i in 9:12) {
     set[[i]] <- 0
@@ -1059,26 +1094,26 @@ shape_options <- function(x){
   return(set)
 }
 
-#Creating a list with a menu for the options:
+# Creating a list with a menu for the options:
 options <- list(
   swap1=al.main.rot,
   swap2=al.mirror,
   swap3=al.trap.rot,
   swap4=al.subtract,
   swap5=al.dot.mov,
-  correct=correct,
+  correct=correct[l],
   add=add.rule,
   automatic=automatic)
 out <- shape_options(options)
 
-#Save all isomorphs into labels "item1", "item2", etc.:
+# Save all isomorphs into labels "item1", "item2", etc.:
 out$a <- a
 out$b <- b
 out$c <- c
 assign(paste("item", l, sep=""), out)
 }
 
-#Creating a mega-list containing all items:
+# Creating a mega-list containing all items:
 items <- 0
 items <- as.list(items)
 for (i in 1:isomorphs) {
